Learn R Programming

njtr1 (version 0.3.2)

get_njtr1: Download New Jersey car accident records for a given year. Returns a data frame of car crash based upon the table type and year specified.

Description

Download New Jersey car accident records for a given year. Returns a data frame of car crash based upon the table type and year specified.

Usage

get_njtr1(year, type, county = "all", geo = FALSE)

Arguments

year

Year to download crash data for

type

The table of NJDOT crash data to download

county

Specify a specific county to download data for (default = all)

geo

Logical, whether to filter only to geotagged cases (default = FALSE)

Value

data.frame of all reported accidents for the year

Examples

Run this code
# NOT RUN {
get_njtr1(year = 2019, type = "Pedestrians")
# }

Run the code above in your browser using DataLab