Learn R Programming

njtr1 (version 0.3.2)

read_njtr1: Read an NJTR-1 data file that was previously downloaded. This function will read a .zip or .txt file in the format published by the NJDOT and return a data frame with cleaned data.

Description

Read an NJTR-1 data file that was previously downloaded. This function will read a .zip or .txt file in the format published by the NJDOT and return a data frame with cleaned data.

Usage

read_njtr1(file, geo = FALSE)

Arguments

file

path to a file downloaded from NJDOT

geo

Logical, whether to filter only to geotagged cases (default = FALSE)

Value

tibble of cleaned & parsed NJTR-1 data

Examples

Run this code
# NOT RUN {
read_njtr1(system.file("extdata/testdata/Ocean2019Accidents.zip", package = "njtr1"))
# }

Run the code above in your browser using DataLab