powered by
Download New Jersey car accident records for a given year. Returns a data frame of car crash based upon the table type and year specified.
get_njtr1(year, type, county = "all", geo = FALSE)
Year to download crash data for
The table of NJDOT crash data to download
Specify a specific county to download data for (default = all)
Logical, whether to filter only to geotagged cases (default = FALSE)
data.frame of all reported accidents for the year
# NOT RUN { get_njtr1(year = 2019, type = "Pedestrians") # }
Run the code above in your browser using DataLab