read_njtr1: Read an NJTR-1 data file that was previously downloaded. This function will read a .zip or .txt file in the format published by the NJDOT and return a data frame with cleaned data.
Description
Read an NJTR-1 data file that was previously downloaded. This function will read a .zip or .txt file in the format published by the NJDOT and return a data frame with cleaned data.
Usage
read_njtr1(file, geo = FALSE)
Arguments
file
path to a file downloaded from NJDOT
geo
Logical, whether to filter only to geotagged cases (default = FALSE)